# Schema


# 1. Protein



* Collection of proteins found to be related to LLPS (LLPS Positive and regulators)
* Attributes fetched from UniProt: "uniprot_id", "uniprot_readable_id", "name", "gene_name", "species_name", "species_tax_id", "ensembl_id", "ensembl_gene_id", "sequence", "llps_ptms", "function"
* Attributes editable by contributors: “functional_type”, “pubmed_ids”
* Attributes autopopulated during _Sync_: “biomolecular_condensate_count”

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td><strong>uniprot_id</strong>
   </td>
   <td>string
   </td>
   <td>Unique identifier for the proteins collection; Fetched from Uniprot.org 
   </td>
  </tr>
  <tr>
   <td>uniprot_readable_id
   </td>
   <td>string
   </td>
   <td>Readable ID from Uniprot; Concatenation of uniprot ID and species name
   </td>
  </tr>
  <tr>
   <td>name
   </td>
   <td>string
   </td>
   <td>Common Name submitted or accepted for the protein as per Uniprot
   </td>
  </tr>
  <tr>
   <td>gene_name
   </td>
   <td>string
   </td>
   <td>Scientific Name of the Gene; Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>species_name
   </td>
   <td>string
   </td>
   <td>Name of the organism where the protein is found; Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>species_tax_id
   </td>
   <td>string
   </td>
   <td>NCBI Taxonomy ID of the organism where the protein is found; Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>ensembl_id
   </td>
   <td>string
   </td>
   <td>ENSEMBL ID; Fetched from Uniprot.org (latest one)
   </td>
  </tr>
  <tr>
   <td>ensembl_gene_id
   </td>
   <td>string
   </td>
   <td>ENSEMBL ID of the gene;  Fetched from Uniprot.org (latest one)
   </td>
  </tr>
  <tr>
   <td>sequence
   </td>
   <td>string
   </td>
   <td>Amino Acid Sequence
   </td>
  </tr>
  <tr>
   <td>llps_ptms
   </td>
   <td>list of strings
   </td>
   <td>List of PTMs helping in LLPS of the protein; Data fetched from <strong><span style="text-decoration:underline;">phase_hu</span></strong>
<p>
PTM is identified by the <em>unique_name </em>from PTMs collection (1.1)
   </td>
  </tr>
  <tr>
   <td>function
   </td>
   <td>string
   </td>
   <td>Functional Description of protein;  Fetched from Uniprot.org
   </td>
  </tr>
  <tr>
   <td>functional_type
<p>
(retired)
   </td>
   <td>enum[string]
   </td>
   <td>(Hierarchical annotation of) Role of the protein in a condensate. Possible values: 
<ol>

<li><strong><em>driver</em></strong>: A protein that undergoes phase separation or self-assembles to form liquid droplets independent of other proteins induces condensate formation or is essential for the integrity of a condensate. This protein is known to be a driver in at least one of the known condensates.

<li><strong><em>client</em></strong>: A protein that is part of condensate but is driven to the condensate by a driver protein. This protein is known to be a client in at least one of the known condensates but has never been known to be a driver.

<li><strong><em>regulator</em></strong>: A protein that biochemically or enzymatically regulates condensate formation but is not a part of the condensate. This protein is never known to be a driver or client.
</li>
</ol>
   </td>
  </tr>
  <tr>
   <td>iupred_score
   </td>
   <td>list of float
   </td>
   <td>IUPred2A Prediction scores; fetched from <a href="https://iupred2a.elte.hu/">https://iupred2a.elte.hu/</a>;
<p>
List of the score at each AA position; Score is from 0 to 1 indicating the possibility of disorder
   </td>
  </tr>
  <tr>
   <td>source_db_tags
   </td>
   <td>list of strings
   </td>
   <td>List of sources which list this protein as LLPS positive; Refer to “Current Sources” explained above for possible source strings and their web links
   </td>
  </tr>
  <tr>
   <td>pubmed_ids
   </td>
   <td>list of strings
   </td>
   <td>List of PubMed IDs which talk about LLPS evidence of this protein.
<p>
As of now, this information is taken from the source databases.
   </td>
  </tr>
  <tr>
   <td>biomolecular_condensate_count
   </td>
   <td>int
   </td>
   <td>Count of occurrence of this protein in biomolecular condensates
   </td>
  </tr>
</table>



## 1.1. PTM



* Only PTMs which lead to LLPS
* The **unique_name **is stored as a property of each protein as **llps_ptms **(foreign key reference; one-to-many)

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td><strong>unique_name</strong>
   </td>
   <td>string
   </td>
   <td>Position appended to name for uniqueness
   </td>
  </tr>
  <tr>
   <td>name
   </td>
   <td>string
   </td>
   <td>Readable Name/Commonly known as
   </td>
  </tr>
  <tr>
   <td>position
   </td>
   <td>string
   </td>
   <td>Position in a protein sequence where the modification is taking place
   </td>
  </tr>
  <tr>
   <td>enzyme
   </td>
   <td>string
   </td>
   <td>
   </td>
  </tr>
  <tr>
   <td>effect_type
   </td>
   <td>categorical
   </td>
   <td>Either “weakens” or “strengthens”
   </td>
  </tr>
  <tr>
   <td>effect_description
   </td>
   <td>string
   </td>
   <td>Textual description of the effect of the PTM
   </td>
  </tr>
</table>



# 2. Condensate



* Collection name is **“condensate_parents”**
* Each entry refers to either a biomolecular membraneless cell organelle or a synthetically created one (in-vitro)
    * The boolean field **“is_experimental” **can be used to identify the type of condensate
* Each record is specific to an organism; meaning two separate entries for nucleolus of human (9606) and mouse (10090)
    * Species could be one of those NCBI Taxonomy IDs we have for proteins or “Chimeras (0000)” for synthetic condensates with proteins from multiple organisms
* Condensate entries are merged as per a **_synonyms_**
* Condensate-specific protein attributes: "protein_pubmed_ids", "protein_source_db_tags", "protein_confidence_score", "protein_driver_criterion", "protein_exp_evidence", "protein_functional_type". 
    * These attributes are usually in the form of a dictionary/hash map, where the key is the protein member’s UniProt ID of condensate, and the; values are respective data points of the protein in context of the said condensate.

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td>name
   </td>
   <td>string
   </td>
   <td>Display Name of the condensate; For synthetic condensates, it is “Synthetic Condensate” followed by a number assigned to each by CD-CODE
   </td>
  </tr>
  <tr>
   <td><strong>uid</strong>
   </td>
   <td>string
   </td>
   <td>Unique Identifier for condensate (yet to be adopted)
   </td>
  </tr>
  <tr>
   <td>synonyms
   </td>
   <td>list of strings
   </td>
   <td>List of names (from source DBs), that refer to the same condensate; Data as per <strong><em>synonyms</em></strong> table
   </td>
  </tr>
  <tr>
   <td>species_name
   </td>
   <td>string
   </td>
   <td>Name of Organism where the proteins are found; “Chimeras” for condensates with proteins from more than 1 condensate
   </td>
  </tr>
  <tr>
   <td>species_tax_id
   </td>
   <td>string
   </td>
   <td>NCBI Taxonomy ID of the organism; 0000 for “Chimeras”
   </td>
  </tr>
  <tr>
   <td>proteins
   </td>
   <td>list of strings
   </td>
   <td>List of all proteins in this condensate.
<p>
Protein is identified by <em>uniport_id </em>from the proteins collections (1)
   </td>
  </tr>
  <tr>
   <td>biomarkers
   </td>
   <td>list of strings
   </td>
   <td>List of protein Uniprot IDs which are found to be markers for this condensate
   </td>
  </tr>
  <tr>
   <td>description
   </td>
   <td>string
   </td>
   <td>Description of the biomolecular cell organelle in few lines
   </td>
  </tr>
  <tr>
   <td>is_experimental
   </td>
   <td>boolean
   </td>
   <td>Two categories of condensates:
<ol>

<li>True: Synthetically prepared

<li>False: Biomolecular Condensate (Membraneless Cell Organelle)
</li>
</ol>
   </td>
  </tr>
  <tr>
   <td>protein_pubmed_ids
   </td>
   <td>dict [string → list of strings]
   </td>
   <td>List of publications (represented by PubMed IDs) per protein in the condensate showing evidence for the respective protein to be a part of the condensate.
<p>
The field can be empty completely for some condensates (Eg: synthetic ones) or not have a key-value pair for some proteins.
<p>
Key: Protein UniProt ID; Value: List of PubMed IDs
   </td>
  </tr>
  <tr>
   <td>protein_source_db_tags
   </td>
   <td>dict [string → list of strings]
   </td>
   <td>List of tags (representing source databases listed for Proteins) per protein in the condensate showing the source of this protein-condensate mapping.
<p>
The field is always present for all proteins in a condensate (at least till now since 11-11-2021)
<p>
Key: Protein UniProt ID; Value: List of <strong><em>source_db_tags</em></strong>
   </td>
  </tr>
  <tr>
   <td>protein_confidence_score
   </td>
   <td>dict [string → int]
   </td>
   <td>Confidence score (0 to 5) for each protein in the given condensate representing how strong the evidence is for the respective protein to be a part of the given condensate.
<p>
Scoring logic is defined in the About Page.
   </td>
  </tr>
  <tr>
   <td>protein_driver_criterion
   </td>
   <td>dict [string → list of strings]
   </td>
   <td>List of criteria the protein satisfies to be known as a driver.
<p>
Possible values:
<ol>

<li>self_ps

<li>essential_for_integrity

<li>induces_assembly
</li>
</ol>
   </td>
  </tr>
  <tr>
   <td>protein_exp_evidence
   </td>
   <td>dict [string → list of strings]
   </td>
   <td>List of experimental evidence supporting the proteins’ presence in the condensate.
<p>
Possible values: 
<ol>

<li>in_vivo

<li>in_vitro

<li>in_cellulo

<li>mass_spectrometry

<li>colocalization

<li>frap

<li>others
</li>
</ol>
   </td>
  </tr>
  <tr>
   <td>protein_functional_type
   </td>
   <td>dict [string → enum[string]]
   </td>
   <td>The functional_type of the given protein in this condensate.
   </td>
  </tr>
  <tr>
   <td>confidence_score
   </td>
   <td>int
   </td>
   <td>A score represents the overall confidence of the existence and proteomic definition of this condensate. Calculated as 
<p>
the median of confidence scores of all proteins in the given condensate.
   </td>
  </tr>
</table>



## 2.1. Experiment



* In-vitro experiments were done at different physicochemical conditions (temperature, PH, concentrations) trying to identify a single or group of proteins’ possibility of phase-separation
* As of now (11-11-2021), the source of such information is **<span style="text-decoration:underline;">llps_db</span>**; Update (01-06-2022) **<span style="text-decoration:underline;">phase_pro_2 </span>**also provides this data
* Each record corresponds to a separate experiment, which has one property as the **“condensate_id”**; This represents the condensate group from the condensates collection (usually synthetic ones)

<table>
  <tr>
   <td>
<strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td><strong>exp_id</strong>
   </td>
   <td>string
   </td>
   <td>Unique Identifier for an experiment
   </td>
  </tr>
  <tr>
   <td>publication_link
   </td>
   <td>string
   </td>
   <td>Link to publication describing the experiment (Pubmed Article)
   </td>
  </tr>
  <tr>
   <td>condensate_id
   </td>
   <td>string
   </td>
   <td>Unique Identifier (canonical_id) of the condensate; The experiment was done using the proteins of this condensate (mostly synthetic)
   </td>
  </tr>
  <tr>
   <td>morphology
   </td>
   <td>categorical
   </td>
   <td>Observation of the experiment’s outcome; Type of the solution (possibly post LLPS)
<p>
Example: Droplet, Liquid Droplet, Transparent Solution
   </td>
  </tr>
  <tr>
   <td>solute_concentrations
   </td>
   <td>string
   </td>
   <td>Semi-colon separated list of concentration for each protein in the condensate
<p>
The protein mentioned as per common name or some modified version of the protein (could be normalised better)
   </td>
  </tr>
  <tr>
   <td>temperature
   </td>
   <td>float
   </td>
   <td>The temperature at which the experiment was conducted; RT means room temperature
   </td>
  </tr>
  <tr>
   <td>ph_value
   </td>
   <td>float
   </td>
   <td>PH of the experimental solution
   </td>
  </tr>
  <tr>
   <td>salt
   </td>
   <td>list of documents
   </td>
   <td>Each salt is identified by another set of attributes (embedded here itself; no FK)

<table>
  <tr>
   <td><strong>Attribute</strong>
   </td>
   <td><strong>Data Type</strong>
   </td>
   <td><strong>Description</strong>
   </td>
  </tr>
  <tr>
   <td>type
   </td>
   <td>string
   </td>
   <td>Salt Compound
   </td>
  </tr>
  <tr>
   <td>concentration
   </td>
   <td>float
   </td>
   <td>Conc in mM
   </td>
  </tr>
</table>


   </td>
  </tr>
  <tr>
   <td>is_phase_separated

   </td>
   <td>boolean

   </td>
   <td>Under given conditions, does phase separation take place?

   </td>
  </tr>
  <tr>
   <td>detection_method

   </td>
   <td>string

   </td>
   <td>Observation technique for LLPS outcome: FRAP, Microscopy, etc.

   </td>
  </tr>
</table>

